@@ -166,6 +166,6 @@ const	char *	current_loader		(void);	 /* XXX command.c */
 	char *	current_package		(void);  /* XXX command.c */
 
 /* keep track of signals for scripted events */
-volatile int     signals_caught[NSIG];
+volatile extern int     signals_caught[NSIG];
 
 #endif /* __irc_h */
