@@ -1219,12 +1219,12 @@ BUILT_IN_COMMAND(funny_stuff)
 			else if (my_strnicmp(arg+1, "PU", 2) == 0) /* PUBLIC */
 			{
 				flags |= FUNNY_PUBLIC;
-				flags &= ~FUNNY_PRIVATE;
+				flags &= ~(FUNNY_PRIVATE);
 			}
 			else if (my_strnicmp(arg+1, "PR", 2) == 0) /* PRIVATE */
 			{
 				flags |= FUNNY_PRIVATE;
-				flags &= ~FUNNY_PUBLIC;
+				flags &= ~(FUNNY_PUBLIC);
 			}
 			else if (my_strnicmp(arg+1, "T", 1) == 0)	/* TOPIC */
 				flags |= FUNNY_TOPIC;
@@ -1427,9 +1427,9 @@ BUILT_IN_COMMAND(license)
 	yell("Copyright (c) 1990 Michael Sandroff.");
 	yell("Copyright (c) 1991, 1992 Troy Rollo.");
  	yell("Copyright (c) 1992-1996 Matthew Green.");
- 	yell("Copyright  1993, 1997 Jeremy Nelson.");
-	yell("Copyright  1994 Jake Khuon.");
-	yell("Coypright  1995, 2004 EPIC Software Labs.");
+ 	yell("Copyright 1993, 1997 Jeremy Nelson.");
+	yell("Copyright 1994 Jake Khuon.");
+	yell("Coypright 1995, 2004 EPIC Software Labs.");
 	yell("All rights reserved");
 	yell(" ");
 	yell("Redistribution and use in source and binary forms, with or");
