@@ -691,7 +691,7 @@ static int	dcc_connected (int fd, int result)
 	 * Set up the connection to be useful
 	 */
 	new_open(dcc->socket);
-	dcc->flags &= ~DCC_THEIR_OFFER;
+	dcc->flags &= ~(DCC_THEIR_OFFER);
 	dcc->flags |= DCC_ACTIVE;
 
 	/*
@@ -1454,7 +1454,7 @@ static	void	dcc_getfile (char *args, int resume)
 			return;
 		}
 
-		if (fullname && *fullname)
+		if (*fullname)
 			strlcat(fullname, "/", sizeof(fullname));
 
 		realfilename = dcc_urldecode(dcc->description);
@@ -2571,7 +2571,7 @@ static	void	process_dcc_chat_connection (DCC_list *Client)
 		return;
 	}
 
-	Client->flags &= ~DCC_MY_OFFER;
+	Client->flags &= ~(DCC_MY_OFFER);
 	Client->flags |= DCC_ACTIVE;
 
 	addr = (SA *)&Client->peer_sockaddr;
@@ -2871,7 +2871,7 @@ static void	process_dcc_send_connection (DCC_list *dcc)
 		return;
 	}
 	new_open(dcc->socket);
-	dcc->flags &= ~DCC_MY_OFFER;
+	dcc->flags &= ~(DCC_MY_OFFER);
 	dcc->flags |= DCC_ACTIVE;
 	get_time(&dcc->starttime);
 
@@ -3493,7 +3493,7 @@ static	void	dcc_getfile_resume_start (const char *nick, char *filename, char *po
 		return;
 	}
 
-	if (fullname && *fullname)
+	if (*fullname)
 		strlcat(fullname, "/", sizeof(fullname));
 
 	realfilename = dcc_urldecode(Client->description);
@@ -3667,7 +3667,7 @@ char *	dccctl (char *input)
 			if (quoted)
 				client->flags |= DCC_QUOTED;
 			else
-				client->flags &= ~DCC_QUOTED;
+				client->flags &= ~(DCC_QUOTED);
 		} else if (!my_strnicmp(listc, "OFFERADDR", len)) {
 			char *host, *port;
 			SS a;
