@@ -6,7 +6,7 @@
  * Copyright (c) 1990 Michael Sandroff.
  * Copyright (c) 1991, 1992 Troy Rollo.
  * Copyright (c) 1992-1996 Matthew Green.
- * Copyright  1993, 2003 EPIC Software Labs
+ * Copyright 1993, 2003 EPIC Software Labs
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -1928,7 +1928,7 @@ static	void	TruncateAndQuote (char **buff, const char *add, ssize_t length, cons
 		 * of the function, so yes, we can reference "add" after
 		 * the end of this block.
 		 */
-		real_size = abs(length) + 1;
+		real_size = labs(length) + 1;
 		buffer = alloca(real_size);
 		add = strformat(buffer, add, length, get_int_var(PAD_CHAR_VAR));
 	}
