@@ -575,11 +575,11 @@ static int	change_ignore_mask_by_desc (const char *type, int *do_mask, int *dont
 		if (mask)
 			*mask |= bit;
 		if (del1)
-			*del1 &= ~bit;
+			*del1 &= ~(bit);
 		if (del2)
-			*del2 &= ~bit;
+			*del2 &= ~(bit);
 		if (del3)
-			*del3 &= ~bit;
+			*del3 &= ~(bit);
 	    }
 	}
 
