@@ -1325,10 +1325,10 @@ void	edit_char (u_char key)
 		if (current_term->TI_meta_mode)
 		{
 			edit_char('\033');
-			key &= ~0x80;
+			key &= ~(0x80);
 		}
 		else if (!term_eight_bit())
-			key &= ~0x80;
+			key &= ~(0x80);
 	}
 
 	extended_key = key;
