@@ -40,19 +40,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC4-2.10.10";
-const char useful_info[] = "epic4 2 10 10";
+const char irc_version[] = "EPIC4-3.0";
+const char useful_info[] = "epic4 3 0 0";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20210325";
+const char internal_version[] = "20240904";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 790;
+const unsigned long	commit_id = 795;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -60,7 +60,7 @@ const unsigned long	commit_id = 790;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Palaver";
+const char ridiculous_version_name[] = "Conducement";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -1153,7 +1153,7 @@ int 	main (int argc, char *argv[])
 		_exit(0);
 
 	/* make sure we don't start with spurious signals events firing */
-	memset(&signals_caught, 0, NSIG * sizeof(int));
+	memset((void *)&signals_caught, 0, NSIG * sizeof(int));
 	/* hook all signals! */
 	init_signals();
 	/* we *might* want to check for SIG_ERR from the above function.
