@@ -1061,13 +1061,13 @@ static void	decifer_mode (const char *modes, Channel *chan)
 	    if (add)
 		chan->mode |= value;
 	    else
-		chan->mode &= ~value;
+		chan->mode &= ~(value);
 	}
 	if (rest && *rest)
 		yell("WARNING:  Mode parser or server is BROKE.  Remaining args: %s", rest);
 
 	if (!chan->limit)
-		chan->mode &= ~MODE_LIMIT;
+		chan->mode &= ~(MODE_LIMIT);
 	else
 		chan->mode |= MODE_LIMIT;
 }
