@@ -1818,7 +1818,7 @@ const 	u_char	*ptr;
 
 					cont = alloca(size);	/* sb pana */
 					snprintf(cont, size,
-						"%-*s", size, cont_ptr);
+						"%-*s", (int)size, cont_ptr);
 				}
 
 				/*
