@@ -1339,7 +1339,7 @@ int 	connect_to_new_server (int new_server, int old_server, int new_conn)
 		 */
 		if (old_server == NOSERV)
 		{
-			if (!(old = get_window_oldserver(0)) != NOSERV)
+			if ((old = get_window_oldserver(0)) != NOSERV)
 				old_server = old;
 		}
 
