@@ -520,6 +520,7 @@ int	make_status (Window *window, int must_redraw)
 			*lhp = lhs_buffer,
 			*rhp = rhs_buffer,
 			*cp,
+			*cp_last,
 			*start_rhs = 0,
 			*str;
 		int	in_rhs = 0,
@@ -650,6 +651,7 @@ int	make_status (Window *window, int must_redraw)
 		 */
 		ptr = str;
 		cp = lhp;
+		cp_last = cp + sizeof(lhs_buffer);
 		lhs_buffer[0] = rhs_buffer[0] = 0;
 
 		while (*ptr)
@@ -691,7 +693,10 @@ int	make_status (Window *window, int must_redraw)
 				fillchar[0] = ' ';
 				fillchar[1] = 0;
 				do
-					*cp++ = ' ';
+				{
+					if (cp_last - cp > 0)
+						*cp++ = ' ';
+				}
 				while (++(*prc) % 8);
 				ptr++;
 			}
