@@ -710,7 +710,7 @@ void	term_putchar (unsigned char c)
 	 * any 8 bit characters we might stumble across.
 	 */
 	if (!(newb.c_cflag & CS8) && (c & 0x80))
-		c &= ~0x80;
+		c &= ~(0x80);
 
 	/*
 	 * Any nonprintable characters we lop off.  In addition to this,
@@ -1097,7 +1097,7 @@ int 	term_init (void)
 #	endif
 
 	if (!use_flow_control)
-		newb.c_iflag &= ~IXON;	/* No XON/XOFF */
+		newb.c_iflag &= ~(IXON);	/* No XON/XOFF */
 
 #if use_alt_screen
 	/* Ugh. =) This is annoying! */
@@ -1209,11 +1209,11 @@ void	set_term_eight_bit (int value)
 	if (value == ON)
 	{
 		newb.c_cflag |= CS8;
-		newb.c_iflag &= ~ISTRIP;
+		newb.c_iflag &= ~(ISTRIP);
 	}
 	else
 	{
-		newb.c_cflag &= ~CS8;
+		newb.c_cflag &= ~(CS8);
 		newb.c_iflag |= ISTRIP;
 	}
 	tcsetattr(tty_des, TCSADRAIN, &newb);
