@@ -476,7 +476,7 @@ void 	init_variables (void)
 					var->func(var->string);
 					break;
 			}
-			var->flags &= ~VIF_PENDING;
+			var->flags &= ~(VIF_PENDING);
 		}
 	}
 }
@@ -677,7 +677,7 @@ void 	set_var_value (int svv_index, char *value)
 		{
 			if (*value)
 			{
-				if ((!var->int_flags & VIF_CHANGED))
+				if (!(var->int_flags & VIF_CHANGED))
 				{
 					if ((var->string && !value) ||
 					    (!var->string && value) ||
@@ -706,7 +706,7 @@ void 	set_var_value (int svv_index, char *value)
 		{
 			var->int_flags |= VIF_PENDING;
 			(var->func) (var->string);
-			var->int_flags &= ~VIF_PENDING;
+			var->int_flags &= ~(VIF_PENDING);
 		}
 
 		say("Value of %s set to %s", var->name, var->string ?
@@ -776,7 +776,7 @@ enum VAR_TYPES	sv_index;
 		}
 
 		if (cnt < 0)
-			irc_variable[sv_index].int_flags &= ~VIF_PENDING;
+			irc_variable[sv_index].int_flags &= ~(VIF_PENDING);
 
 		if (hook)
 		{
