@@ -94,7 +94,7 @@ static const char *	find_forward_character (const char *input, const char *start
 	else
 	{
 		simple = 0;
-		what = 255;
+		what = -1;
 	}
 
 	/*
@@ -164,7 +164,7 @@ static const char *	find_backward_quote (const char *input, const char *start, c
 	else
 	{
 		simple = 0;
-		what = 255;
+		what = -1;
 	}
 
 	/*
@@ -287,7 +287,7 @@ static int	move_to_prev_word (const char **str, const char *start, int extended,
 		if (x_debug & DEBUG_EXTRACTW_DEBUG)
 			yell(".... move_to_prev_word: Expensive processing");
 		simple = 0;
-		what = 255;
+		what = -1;
 	}
 
 	/* Overhead -- work out if we're doing "" support or not. */
@@ -481,7 +481,7 @@ static int	move_to_next_word (const char **str, const char *start, int extended,
 		if (x_debug & DEBUG_EXTRACTW_DEBUG)
 			yell(".... move_to_next_word: Expensive processing");
 		simple = 0;
-		what = 255;
+		what = -1;
 	}
 
 	/*
